@@ -115,17 +115,19 @@ Print.prototype.createPrinter = function(pdfFile, printerName, pdfVersion) {
         }
     }
 
-    var paperSizeEnum = Print.getPaperSizeEnum(this.document);
-    if (paperSizeEnum!==QPrinter.Custom) {
-        printer.setPaperSize(paperSizeEnum);
+    // always use custom page size to work around Qt page size limitations:
+    var paperSizeMM = Print.getPaperSizeMM(this.document);
+    if (RSettings.getQtVersion() >= 0x060000) {
+        printer.setPageSize(new QPageSize(paperSizeMM, QPageSize.Millimeter));
+        printer.setFullPage(true);
+        printer.setPageOrientation(Print.getPageOrientationEnum(this.document));
     }
     else {
-        //printer.setPaperSize(QPrinter.Custom);
-        var paperSizeMM = Print.getPaperSizeMM(this.document);
         printer.setPaperSize(paperSizeMM, QPrinter.Millimeter);
+        printer.setFullPage(true);
+        printer.setOrientation(Print.getPageOrientationEnum(this.document));
     }
-    printer.setFullPage(true);
-    printer.setOrientation(Print.getPageOrientationEnum(this.document));
+
 
     var colorMode = Print.getColorMode(this.document);
     if (colorMode == RGraphicsView.FullColor) {
@@ -267,9 +269,17 @@ Print.prototype.printCurrentBlock = function(printer, painter) {
     var heightInMM = printer.paperRect(QPrinter.Millimeter).height();
 
     // factor from mm to printer unit:
+    var paperRect;
+    if (RSettings.getQtVersion() >= 0x060000) {
+        paperRect = printer.pageLayout().fullRectPixels(printer.resolution());
+    }
+    else {
+        paperRect = printer.paperRect();
+    }
+
     var printerFactor = new RVector(
-        printer.paperRect().width() / widthInMM,
-        printer.paperRect().height() / heightInMM
+        paperRect.width() / widthInMM,
+        paperRect.height() / heightInMM
     );
 
     // printer calibration:
@@ -291,8 +301,8 @@ Print.prototype.printCurrentBlock = function(printer, painter) {
     var previousPixelSizeHint = this.scene.getPixelSizeHint();
 
     var widthInDrawingUnits = RUnit.convert(widthInMM, RS.Millimeter, this.document.getUnit());
-    if (printer.paperRect().width()>0) {
-        var pixelSizeHint = 1.0/printer.paperRect().width()*widthInDrawingUnits;
+    if (paperRect.width()>0) {
+        var pixelSizeHint = 1.0/paperRect.width()*widthInDrawingUnits;
         pixelSizeHint = pixelSizeHint / scale;
         this.scene.setPixelSizeHint(pixelSizeHint);
     }
@@ -331,7 +341,7 @@ Print.prototype.printCurrentBlock = function(printer, painter) {
         if (!qclr.equals(new QColor(Qt.white))) {
             painter.setWorldTransform(new QTransform());
             painter.setBackground(new QBrush(qclr, Qt.SolidPattern));
-            painter.eraseRect(printer.paperRect());
+            painter.eraseRect(paperRect);
         }
 
         // paper size in mm:
@@ -465,10 +475,10 @@ Print.autoFitDrawing = function(di, ori) {
     //qDebug("bb: ", bBox);
     if (ori) {
         if (bBox.getWidth()>bBox.getHeight()) {
-            Print.setPageOrientationEnum(di, QPrinter.Landscape);
+            Print.setPageOrientationEnum(di, RS.Landscape);
         }
         else {
-            Print.setPageOrientationEnum(di, QPrinter.Portrait);
+            Print.setPageOrientationEnum(di, RS.Portrait);
         }
     }
     Print.autoFitBox(di, bBox);
@@ -824,7 +834,7 @@ Print.getPages = function(document) {
     var w;
     var h;
     var paperSizeMM = Print.getPaperSizeMM(document);
-    if (Print.getPageOrientationEnum(document) === QPrinter.Portrait) {
+    if (Print.getPageOrientationEnum(document) === RS.Portrait) {
         w = paperSizeMM.width();
         h = paperSizeMM.height();
     } else {
@@ -1160,11 +1170,53 @@ Print.getPaperSizeMM = function(document) {
  * or QPrinter.
  */
 Print.getDefaultPaperSizeMM = function() {
-    var defaultPaperSizeMM = Print.getDefaultPrinter().paperSize(QPrinter.Millimeter);
+    var defaultPrinter = Print.getDefaultPrinter();
 
-    var dwMM = defaultPaperSizeMM.width();
-    var dhMM = defaultPaperSizeMM.height();
+    var dwMM;
+    var dhMM;
 
+    if (RSettings.getQtVersion() >= 0x060000) {
+        var defaultPaperSize = defaultPrinter.pageLayout().pageSize();
+
+        // paper size in appropriate unit:
+        var size = defaultPaperSize.definitionSize();
+        var wUnit = size.width();
+        var hUnit = size.height();
+
+        // unit of paper size:
+        var unit = defaultPaperSize.definitionUnits();
+
+        // convert unit to mm:
+        var factor = 1.0;
+        switch (unit) {
+        case QPageSize.Point:
+            factor = 72 / 25.4;
+            break;
+        case QPageSize.Inch:
+            factor = 25.4;
+            break;
+        case QPageSize.Pica:
+            factor = 6 / 25.4;
+            break;
+        case QPageSize.Didot:
+            factor = 1 / 0.365;
+            break;
+        case QPageSize.Cicero:
+            factor = 1 / 4.5;
+            break;
+        default:
+        case QPageSize.Millimeter:
+            factor = 1.0;
+            break;
+        }
+        dwMM = wUnit * factor;
+        dhMM = hUnit * factor;
+    }
+    else {
+        var defaultPaperSizeMM = defaultPrinter.paperSize(QPrinter.Millimeter);
+        dwMM = defaultPaperSizeMM.width();
+        dhMM = defaultPaperSizeMM.height();
+    }
     // get w / h in paper unit from settings:
     var dw = RUnit.convert(dwMM, RS.Millimeter, Print.getDefaultPaperUnit());
     var dh = RUnit.convert(dhMM, RS.Millimeter, Print.getDefaultPaperUnit());
@@ -1249,7 +1301,7 @@ Print.getPaperSizeEnum = function(document) {
         }
     }
 
-    return QPrinter.Custom;
+    return undefined;
 };
 
 /**
@@ -1363,10 +1415,10 @@ Print.getDefaultPaperSizeName = function(document) {
 Print.getPageOrientationEnum = function(document) {
     var pageOrientationString = Print.getPageOrientationString(document);
     if (pageOrientationString==="Landscape") {
-        return QPrinter.Landscape;
+        return RS.Landscape;
     }
     else {
-        return QPrinter.Portrait;
+        return RS.Portrait;
     }
 };
 
@@ -1379,7 +1431,7 @@ Print.setPageOrientationString = function(di, pageOrientation) {
 };
 
 Print.setPageOrientationEnum = function(di, pageOrientation) {
-    if (pageOrientation.valueOf()===QPrinter.Landscape.valueOf()) {
+    if (pageOrientation===RS.Landscape) {
         Print.setPageOrientationString(di, "Landscape");
     }
     else {
