@@ -171,15 +171,16 @@ WidgetFactory.getKey = function(group, obj) {
     var key = [g, obj.objectName];
 
     // correct key:
-    if (obj.toString() === "QRadioButton" || obj.toString() === "QToolButton") {
+    if (isOfType(obj, QRadioButton) || isOfType(obj, QToolButton)) {
         // correct to button group name:
-        if (isFunction(obj.group) && obj.group()) {
+
+        if (isFunction(obj.group) && !isNull(obj.group())) {
             key = [g, obj.group().objectName];
         }
         else {
             var parent = obj.parent();
             // correct to group box (parent) name:
-            if (parent && parent.toString()=="QGroupBox") {
+            if (parent && isOfType(parent, QGroupBox)) {
                 key = [g, parent.objectName];
             }
         }
@@ -253,8 +254,8 @@ WidgetFactory.saveState = function(widget, group, document, map) {
     for (var i = 0; i < children.length; ++i) {
         var c = children[i];
 
-        if (!c || isDeleted(c) || c.toString()==="QVariantAnimation" ||
-                c.toString()==="QWidgetAction" || c.objectName==="" ||
+        if (!c || isDeleted(c) || c.toString().startsWith("QVariantAnimation") ||
+                c.toString().startsWith("QWidgetAction") || c.objectName==="" ||
                 c.objectName==="Icon" || c.objectName==="qt_toolbar_ext_button") {
             continue;
         }
@@ -267,12 +268,12 @@ WidgetFactory.saveState = function(widget, group, document, map) {
 
         // ignore widgets that have been saved elsewhere (e.g. plugins might
         // save widgets contents by themselves in savePreferences):
-        if (typeof(c["Saved"]) != "undefined" && c["Saved"]===true) {
+        if (typeof(c.property("Saved")) != "undefined" && c.property("Saved")===true) {
             continue;
         }
 
         // skip children from other groups in this widget (for options toolbar):
-        if (typeof(c["SettingsGroup"]) != "undefined" && c["SettingsGroup"] != group) {
+        if (typeof(c.property("SettingsGroup")) != "undefined" && c.property("SettingsGroup") != group) {
             if (isNull(map)) {
                 continue;
             }
@@ -316,12 +317,12 @@ WidgetFactory.saveState = function(widget, group, document, map) {
         else if (isOfType(c, QComboBox) || isOfType(c, QFontComboBox)) {
             var forceSaveText = false;
             var forceSaveIndex = false;
-            if (typeof(c["ForceSaveText"]) != "undefined"
-                    && c["ForceSaveText"] === true) {
+            if (typeof(c.property("ForceSaveText")) != "undefined"
+                    && c.property("ForceSaveText") === true) {
                 forceSaveText = true;
             }
-            if (typeof(c["ForceSaveIndex"]) != "undefined"
-                    && c["ForceSaveIndex"] === true) {
+            if (typeof(c.property("ForceSaveIndex")) != "undefined"
+                    && c.property("ForceSaveIndex") === true) {
                 forceSaveIndex = true;
             }
             if (forceSaveIndex == true) {
@@ -386,23 +387,23 @@ WidgetFactory.saveState = function(widget, group, document, map) {
         }
 
         // save property
-        if (typeof(c["SaveProperty"]) != "undefined") {
-            var prop = c["SaveProperty"];
+        if (typeof(c.property("SaveProperty")) != "undefined") {
+            var prop = c.property("SaveProperty");
             RSettings.setValue(key + "." + prop, c[prop]);
         }
 
         // widgets with dynamic property "RequiresRestart" trigger a
         // restart application warning after changing preferences:
-        if (typeof(c["RequiresRestart"]) != "undefined"
-            && c["RequiresRestart"] === true) {
+        if (typeof(c.property("RequiresRestart")) != "undefined"
+            && c.property("RequiresRestart") === true) {
             WidgetFactory.requiresRestart = true;
         }
 
         // widgets can be ignored by setting the dynamic property
         // "SaveContents" = false
         var saveContents = true;
-        if (typeof(c["SaveContents"]) != "undefined"
-                && c["SaveContents"] === false) {
+        if (typeof(c.property("SaveContents")) != "undefined"
+                && c.property("SaveContents") === false) {
             saveContents = false;
         }
 
@@ -461,7 +462,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
     }
 
     // Qt5: QWebView has no scriptable children method:
-    if (!isFunction(widget["children"])) {
+    if (!isFunction(widget.children)) {
         return;
     }
 
@@ -470,7 +471,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
         var c = children[i];
         
         if (!c || isDeleted(c)) {
-            break;
+            continue;
         }
 
         // ignore widgets without name:
@@ -490,7 +491,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
 
         // skip children from other groups in this widget (for options toolbar):
         // but not if used from a test [map != undefined]
-        if (isNull(map) && typeof (c["SettingsGroup"]) != "undefined" && c["SettingsGroup"] !== group) {
+        if (isNull(map) && typeof (c.property("SettingsGroup")) != "undefined" && c.property("SettingsGroup") !== group) {
             continue;
         }
 
@@ -501,7 +502,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
 
         // handle widgets which have their own reset method
         var hasOwnReset = false;
-        if (typeof(c["hasOwnReset"]) != "undefined" && c["hasOwnReset"] == true) {
+        if (typeof(c.property("hasOwnReset")) != "undefined" && c.property("hasOwnReset") == true) {
             hasOwnReset = true;
         }
         if (reset && hasOwnReset) {
@@ -513,7 +514,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
         
         var key = WidgetFactory.getKeyString(group, c);
         var value = undefined;
-        if (reset && !isNull(c.property("defaultValue")) && (typeof(c["SettingsGroup"])=="undefined" || c["SettingsGroup"]===group)) {
+        if (reset && !isNull(c.property("defaultValue")) && (typeof(c.property("SettingsGroup"))=="undefined" || c.property("SettingsGroup")===group)) {
             value = c.property("defaultValue");
         } else {
             if (!isNull(map)) {
@@ -545,14 +546,13 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
         // don't restore widgets that have been restored elsewhere (e.g. script
         // add-ons might load widgets contents by themselves in initPreferences):
         // [but always restore widgets if used from a test (map != undefined)]
-        if (isNull(map) && !reset && typeof (c["Loaded"]) != "undefined"
-                && c["Loaded"] === true) {
+        if (isNull(map) && !reset && c.property("Loaded")===true) {
             value = undefined;
         }
 
         // restore property
-        if (typeof(c["SaveProperty"]) != "undefined") {
-            var prop = c["SaveProperty"];
+        if (typeof(c.property("SaveProperty")) != "undefined") {
+            var prop = c.property("SaveProperty");
             var val = RSettings.getValue(key + "." + prop);
             if (!isNull(val)) {
                 c[prop] = val;
@@ -635,7 +635,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
                 c.setProperty("defaultValue", c.text);
             }
             if (!isNull(value)) {
-                c.text = value;
+                c.text = value.toString();
             }
             continue;
         }
@@ -716,7 +716,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             }
             if (isNull(c.property("defaultValue"))) {
                 var button = c.checkedButton();
-                if (button) {
+                if (!isNull(button) && !isNull(button.objectName)) {
                     c.setProperty("defaultValue", button.objectName);
                     if (!isNull(signalReceiver)) {
                         f = signalReceiver["slot"+c.objectName+"Changed"];
@@ -772,12 +772,14 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
                 WidgetFactory.connect(c['currentIndexChanged(int)'], WidgetFactory.topLevelWidget, "Setting");
             }
             hasData = false;
-            if (c.itemData(c.currentIndex)!=undefined) {
+            if (c.itemData(c.currentIndex)!=undefined || (c.count>0 && c.itemData(0)!=undefined)) {
                 hasData = true;
             }
             if (isNull(c.property("defaultValue"))) {
                 if (hasData) {
-                    c.setProperty("defaultValue", c.itemData(c.currentIndex));
+                    if (c.currentIndex>=0 && c.currentIndex<c.count) {
+                        c.setProperty("defaultValue", c.itemData(c.currentIndex));
+                    }
                 } else {
                     c.setProperty("defaultValue", c.currentText);
                 }
@@ -790,22 +792,25 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             }
             var forceSaveText = false;
             var forceSaveIndex = false;
-            if (typeof(c["ForceSaveText"]) != "undefined"
-                    && c["ForceSaveText"] == true) {
+            if (typeof(c.property("ForceSaveText")) != "undefined"
+                    && c.property("ForceSaveText") == true) {
                 forceSaveText = true;
             }
-            if (typeof(c["ForceSaveIndex"]) != "undefined"
-                    && c["ForceSaveIndex"] == true) {
+            if (typeof(c.property("ForceSaveIndex")) != "undefined"
+                    && c.property("ForceSaveIndex") == true) {
                 forceSaveIndex = true;
             }
             if (!isNull(value)) {
+                index = -1;
                 if (forceSaveIndex == true) {
                     index = value;
                 }
                 else if (forceSaveText == false && hasData) {
                     index = c.findData(value);
                 } else {
-                    index = c.findText(value);
+                    if (isString(value)) {
+                        index = c.findText(value);
+                    }
                 }
                 if (index !== -1) {
                     c.currentIndex = index;
@@ -923,8 +928,8 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
             // if the list contents should not be saved to
             // the configuration file or document:
             var saveContents = true;
-            if (typeof(c["SaveContents"]) != "undefined"
-                    && c["SaveContents"] == false) {
+            if (typeof(c.property("SaveContents")) != "undefined"
+                    && c.property("SaveContents") == false) {
                 saveContents = false;
             }
 
@@ -988,8 +993,8 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
 
             if (!reset) {
                 WidgetFactory.connect(c.itemChanged, signalReceiver, c.objectName);
-                c.itemSelectionChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
-                c.model().rowsInserted.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
+                c.itemSelectionChanged.connect(WidgetFactory.topLevelWidget, WidgetFactory.topLevelWidget.slotSettingChanged);
+                c.model().rowsInserted.connect(WidgetFactory.topLevelWidget, WidgetFactory.topLevelWidget.slotSettingChanged);
             }
             
             continue;
@@ -997,7 +1002,7 @@ WidgetFactory.restoreState = function(widget, group, signalReceiver, reset, docu
         if (isOfType(c, RFontChooserWidget)) {
             if (!reset) {
                 WidgetFactory.connect(c.valueChanged, signalReceiver, c.objectName);
-                c.valueChanged.connect(WidgetFactory.topLevelWidget, "slotSettingChanged");
+                c.valueChanged.connect(WidgetFactory.topLevelWidget, WidgetFactory.topLevelWidget.slotSettingChanged);
             }
             if (isNull(c.property("defaultValue"))) {
                 c.setProperty("defaultValue", c.getChosenFont());
